
from packaging import version
import subprocess
import platform
import ziion_cli.dispatcher
import ziion_cli.utils

def installed_versions():
    output = subprocess.check_output(["cargo","install-update","--list"])
    return ziion_cli.utils.parse_str_to_dict(output.decode("utf-8"))


def list_packages_to_be_updated(s3_packages_list, local_packages_list):
    packages_to_update=[]
    print ("\n{:<15} {:<15} {:<15}".format('Package','Installed','Latest'))
    print ("-"*40)
    for package in s3_packages_list:
        if package in local_packages_list:
            if version.parse(s3_packages_list[package]) > version.parse(local_packages_list[package]):
                print ("{:<15} {:<15} {:<15}".format(package,local_packages_list[package], s3_packages_list[package]))
                packages_to_update.append(package)
    print("\n")
    return packages_to_update

def update_necessary_packages(s3_packages_list, local_packages_list):
    print("\nPackages to be updated:")
    packages = ziion_cli.dispatcher.list_packages_to_be_updated(s3_packages_list, local_packages_list)
    for package in packages:
        if platform.machine() == 'x86_64':
            s3_folder = "rust-amd-binaries/"
        elif platform.machine() == 'aarch64':
            s3_folder = "rust-arm-binaries/"
        download = subprocess.run(["wget", "-O", package, "https://ziion-binaries.s3.amazonaws.com/"+ s3_folder + package], 
            stdout=subprocess.DEVNULL,
            stderr=subprocess.STDOUT)
        if download.returncode == 0:
            print(package + " updated succesfully.")
        else:
            print(package + " could not be updated correctly.")
    print("\n")